use nhanes2-cetus 
* Chunk 1: Clear prior collections, define macros
collect clear
global outcome tcresult
global step1 bmi
global step2 bpsystol bpdiast
global step3 age
global worddoc nestreg2.docx       
* Chunk 2: Collect results
***** Collect model 1
collect, tag(model[1]): regress $outcome $step1
  * Save "r2old" for next step
  global r2old = e(r2)
***** Collect model 2
collect, tag(model[2]): regress $outcome $step1 $step2
  * Compute "change statistics"
  collect get r2ch = (e(r2) - $r2old), tag(model[2])
  test $step2
  collect get fch = (r(F)), tag(model[2])
  collect get pch = (r(p)), tag(model[2])
  * Save "r2old" for next step
  global r2old = e(r2)
***** Collect model 3
collect, tag(model[3]): regress tcresult $step1 $step2 $step3 
  * Compute "change statistics"
  collect get r2ch = (e(r2) - $r2old), tag(model[3])
  test $step3
  collect get fch = (r(F)), tag(model[3])
  collect get pch = (r(p)), tag(model[3])   
* Chunk 3: Define composite
collect composite define coefse = _r_b _r_se, trim   
* Chunk 4: Format results
collect style cell result[_r_se], sformat("(%s)")
collect style cell result[coefse fch], nformat(%5.2f)
collect style cell result[r2 r2ch], nformat(%5.3f)
collect style cell result[pch], nformat(%5.3f) minimum(0.001)  
* Chunk 5: Label results
collect label levels model 1 "Model 1" 2 "Model 2" 3 "Model 3"  
collect label levels result r2 "𝑅²" r2ch "Δ𝑅²" fch "Δ𝐹"                ///
  pch "𝑝-value", modify             
* Chunk 6: Add stars; hide header; add notes; intercept first
collect stars _r_p 0.001 "***" 0.01 "**" 0.05 "*", attach(_r_b) shownote
collect style header result[coefse], level(hide)
collect notes "Results show coefficient with standard error in parentheses."
collect style _cons first    
* Chunk 7: Create tags for headers
collect addtags modhd["Δ Statistics"], fortags(result[r2ch fch pch])
collect addtags varhd["Step 1"], fortags(colname[$step1])
collect addtags varhd["Step 2"], fortags(colname[$step2])
collect addtags varhd["Step 3"], fortags(colname[$step3])    
* Chunk 8: Lay out table
collect layout                                                         ///
  (varhd#colname#result[coefse] result[r2] modhd#result[r2ch fch pch]) ///
  (model)        
* Chunk 9: Export table as Word document
collect style putdocx, layout(autofitcontents) 
collect export $worddoc
